@@ -89,10 +89,12 @@ MOVETEXT_REGEX = re.compile(r"""
         [NBKRQ]?[a-h]?[1-8]?[\-x]?[a-h][1-8](?:=?[nbrqkNBRQK])?
         |[PNBRQK]?@[a-h][1-8]
         |--
+        |Z0
         |O-O(?:-O)?
         |0-0(?:-0)?
     )
     |(\{.*)
+    |(;.*)
     |(\$[0-9]+)
     |(\()
     |(\))
@@ -895,6 +897,8 @@ def read_game(handle, Visitor=GameModelCreator):
                 if line:
                     read_next_line = False
                 break
+            elif token.startswith(";"):
+                break
             elif token.startswith("$"):
                 # Found a NAG.
                 try:
